@@ -5,7 +5,7 @@ import logging as _logging
 from . import spells, types
 from ._group import TodoGroup
 from ._magic import MagicTodoMixin
-from ._shared import DEFAULT_PRIORITY, to_date
+from ._shared import DEFAULT_PRIORITY, from_date, to_date
 from ._todo import Todo
 
 
@@ -14,6 +14,7 @@ __all__ = [
     "MagicTodoMixin",
     "Todo",
     "TodoGroup",
+    "from_date",
     "spells",
     "to_date",
     "types",
@@ -21,6 +22,6 @@ __all__ = [
 
 __author__ = "Bryan M Bugyi"
 __email__ = "bryanbugyi34@gmail.com"
-__version__ = "0.8.0"
+__version__ = "0.8.1"
 
 _logging.getLogger(__name__).addHandler(_logging.NullHandler())
