@@ -26,8 +26,6 @@ from typist import Comparable
 # Type Variables (i.e. `TypeVar`s)
 T = TypeVar("T", bound="AbstractTodo")
 
-# Type of a spell function which transforms a line (i.e. a str).
-LineSpell = Callable[[str], str]
 # Type of the Todo.metadata attribute.
 Metadata = Dict[str, Union[str, List[str]]]
 # A todo item's priority is always a capital letter.
@@ -59,14 +57,25 @@ Priority = Literal[
     "Y",
     "Z",
 ]
+
+# Type of a spell function which transforms a line (i.e. a str).
+LineSpell = Callable[[str], str]
 # Type of spell functions used by MagicTodo objects.
-TodoSpell = Callable[[T], Result[T, ErisError]]
+TodoSpell = Callable[[T], T]
+# Type of spell that validates a todo line.
+ValidateSpell = Callable[[str], Result[None, ErisError]]
+
+MetadataChecker = Callable[[str], bool]
 
 
 @runtime_checkable
 class AbstractTodo(Comparable, Protocol):
     """Describes how any valid Todo object should look."""
 
+    @property
+    def ident(self) -> str:
+        """A unique identifier for this Todo."""
+
     @classmethod
     def from_line(cls: Type[T], line: str) -> Result[T, ErisError]:
         """Constructs a new Todo object from a string."""
@@ -126,6 +135,7 @@ class AbstractMagicTodo(AbstractTodo, Protocol, Generic[T]):
     to_line_spells: List[LineSpell]
     from_line_spells: List[LineSpell]
     todo_spells: List[TodoSpell]
+    validate_spells: List[ValidateSpell]
 
     def __init__(self, todo: T) -> None:
         pass
